@@ -32,10 +32,10 @@ our $IS_AUTHOR = 0;
 
 # UNCOMMENT AND CONFIGURE FOR MONGO USAGE
 
-#our $MONGO_DB = undef;
-our $MONGO_DB   = 'hockeytest';
-our $MONGO_HOST = '127.0.0.1';
-our $MONGO_PORT = 27017;
+our $MONGO_DB = undef;
+#our $MONGO_DB   = 'hockeytest';
+#our $MONGO_HOST = '127.0.0.1';
+#our $MONGO_PORT = 27017;
 
 our $DATA_DIR = '/misc/nhl';
 
